@@ -3,7 +3,7 @@ use 5.006;
 use strict;
 use warnings;
 use Carp;
-our $VERSION = '1.1';
+our $VERSION = '1.3';
 use constant DUMMY => sub {};
 my $magic = "fOrTyTwO";
 
@@ -14,12 +14,12 @@ Devel::DProfPP - Parse C<Devel::DProf> output
 =head1 SYNOPSIS
 
   use Devel::DProfPP;
-  my $pp = Devel::DProfPP->new
+  my $pp = Devel::DProfPP->new;
 
   Devel::DProfPP->new(
         file    => "../tmon.out",
         enter   => sub { my ($self, $sub_name)  = shift;
-                         my $topframe = ($self->stack)[-1];
+                         my $frame = ($self->stack)[-1];
                          print "\t" x $frame->height, $frame->sub_name;
                        }
   )->parse;
@@ -79,7 +79,10 @@ sub _parse_header {
     my ($over_tests, $rrun_utime, $rrun_stime, $rrun_rtime, $total_marks);
     my $fh = $self->{fh};
     my $head = <$fh>;
-    croak "This isn't really DProf output" unless $head =~ /$magic/;
+    if(!defined $head || $head !~ /$magic/) {
+        croak "This isn't really DProf output";
+    }
+
     while (<$fh>) {
         last if /^PART2/;
         eval;
@@ -185,6 +188,8 @@ of a subroutine call. C<Devel::DProfPP> doesn't do this for you.
 
 The user, system and real times (in cycles) for the whole program run.
 
+=back 
+
 =cut
 
 sub header { $_[0]->{header} }
@@ -298,7 +303,8 @@ omission should't make any real difference.
 
 =head1 AUTHOR
 
-Simon Cozens, C<simon@cpan.org>
+Simon Cozens is the original author.  Currently maintained by 
+Steve Peters, C<steve@fisharerojo.org>
 
 =head1 LICENSE
 
